@@ -19,7 +19,7 @@ class Country(models.Model):
 
 
 class Area(models.Model):
-    country = models.ForeignKey(Country)
+    country = models.ForeignKey(Country, verbose_name=_('Country'))
     name = models.CharField(_('Area'), max_length=255)
 
     def __unicode__(self):
@@ -35,9 +35,11 @@ class City(models.Model):
     area = models.ForeignKey(Area)
     name = models.CharField(_('City name'), max_length=255)
     latitude = models.DecimalField(
-        max_digits=9, decimal_places=6, blank=True, null=True)
+        max_digits=9, decimal_places=6, blank=True, null=True,
+        verbose_name=_('Latitude'))
     longitude = models.DecimalField(
-        max_digits=9, decimal_places=6, blank=True, null=True)
+        max_digits=9, decimal_places=6, blank=True, null=True,
+        verbose_name=_('Longitude'))
 
     def __unicode__(self):
         return self.name
@@ -50,7 +52,7 @@ class City(models.Model):
 
 class ISP(models.Model):
     name = models.CharField('ISP', max_length=255)
-    country = models.ForeignKey(Country)
+    country = models.ForeignKey(Country, verbose_name=_('Country'))
 
     def __unicode__(self):
         return self.name
@@ -63,7 +65,7 @@ class ISP(models.Model):
 
 class Provider(models.Model):
     name = models.CharField(_('Provider'), max_length=255, unique=True)
-    isp = models.ManyToManyField(ISP, blank=True)
+    isp = models.ManyToManyField(ISP, blank=True, verbose_name=_('ISP'))
     ranges = models.TextField(
         _('Provider network ranges'), blank=True, null=True)
 
@@ -83,11 +85,12 @@ class Provider(models.Model):
 class Range(models.Model):
     start_ip = models.BigIntegerField(_('Start range'), db_index=True)
     end_ip = models.BigIntegerField(_('End range'), db_index=True)
-    country = models.ForeignKey(Country)
-    area = models.ForeignKey(Area, null=True)
-    city = models.ForeignKey(City, null=True)
-    isp = models.ForeignKey(ISP, null=True)
-    provider = models.ForeignKey(Provider, null=True)
+    country = models.ForeignKey(Country, verbose_name=_('Country'))
+    area = models.ForeignKey(Area, verbose_name=_('Area'), null=True)
+    city = models.ForeignKey(City, verbose_name=_('City'), null=True)
+    isp = models.ForeignKey(ISP, verbose_name=_('ISP'), null=True)
+    provider = models.ForeignKey(
+        Provider, verbose_name=_('Provider'), null=True)
 
     @classmethod
     def by(cls, start, end):
